# crossplain

A small layer atop NGINX's [crossplane](https://github.com/nginxinc/crossplane) that uses Python objects instead of dicts from JSON.

[![PyPI](https://img.shields.io/pypi/v/crossplain)](https://pypi.org/project/crossplain)

<!-- TODO: #1 documentation -->
